aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/release_ref.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/release_ref.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_ref.py25
1 files changed, 13 insertions, 12 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/release_ref.py b/python_openapi_client/fatcat_openapi_client/models/release_ref.py
index 42131973..1fd5288d 100644
--- a/python_openapi_client/fatcat_openapi_client/models/release_ref.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_ref.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -18,22 +18,23 @@ import six
class ReleaseRef(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'index': 'int',
'target_release_id': 'str',
- 'extra': 'object',
+ 'extra': 'dict(str, object)',
'key': 'str',
'year': 'int',
'container_name': 'str',
@@ -53,7 +54,7 @@ class ReleaseRef(object):
}
def __init__(self, index=None, target_release_id=None, extra=None, key=None, year=None, container_name=None, title=None, locator=None): # noqa: E501
- """ReleaseRef - a model defined in Swagger""" # noqa: E501
+ """ReleaseRef - a model defined in OpenAPI""" # noqa: E501
self._index = None
self._target_release_id = None
@@ -129,8 +130,8 @@ class ReleaseRef(object):
raise ValueError("Invalid value for `target_release_id`, length must be less than or equal to `26`") # noqa: E501
if target_release_id is not None and len(target_release_id) < 26:
raise ValueError("Invalid value for `target_release_id`, length must be greater than or equal to `26`") # noqa: E501
- if target_release_id is not None and not re.search('[a-zA-Z2-7]{26}', target_release_id): # noqa: E501
- raise ValueError("Invalid value for `target_release_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
+ if target_release_id is not None and not re.search(r'[a-zA-Z2-7]{26}', target_release_id): # noqa: E501
+ raise ValueError(r"Invalid value for `target_release_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
self._target_release_id = target_release_id
@@ -141,7 +142,7 @@ class ReleaseRef(object):
Additional free-form JSON metadata about this citation. Generally follows Citation Style Language (CSL) JSON schema. See guide for details. # noqa: E501
:return: The extra of this ReleaseRef. # noqa: E501
- :rtype: object
+ :rtype: dict(str, object)
"""
return self._extra
@@ -152,7 +153,7 @@ class ReleaseRef(object):
Additional free-form JSON metadata about this citation. Generally follows Citation Style Language (CSL) JSON schema. See guide for details. # noqa: E501
:param extra: The extra of this ReleaseRef. # noqa: E501
- :type: object
+ :type: dict(str, object)
"""
self._extra = extra
@@ -276,7 +277,7 @@ class ReleaseRef(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -18,22 +18,23 @@ import six
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name